package com.vaartatechnologies.all_in_one_basic;

import android.app.Activity;
import android.content.Context;
import android.widget.Toast;

import androidx.annotation.NonNull;

import com.vaartatechnologies.all_in_one_basic.includes.SmallFunctions;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/** AllInOneBasicPlugin */
public class AllInOneBasicPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {

  private MethodChannel channel;
  private Context context;
  private Activity activity;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "all_in_one_basic");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    switch (call.method) {
      case "getPlatformVersion" -> result.success("Android " + android.os.Build.VERSION.RELEASE);
      case "share" -> SmallFunctions.shareAction(activity, call.argument("message"));
      case "showToast" -> SmallFunctions.createToast(context, call.argument("message"), call.argument("duration"));
      case "internet" -> result.success(SmallFunctions.returnInternet(context));
      case "internetType" -> result.success(SmallFunctions.returnInternetType(context));
      case "randomNumbers" -> result.success(SmallFunctions.getRandomNumbers(call.argument("min"), call.argument("max")));
      case "randomAlphaNumeric" -> result.success(SmallFunctions.getRandomAlphaNumeric(call.argument("digits")));
      default -> result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  // ActivityAware Starts

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
    this.context = binding.getActivity().getApplicationContext();
    this.activity = binding.getActivity();
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {
    this.context = null;
    this.activity = null;
  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
    this.context = binding.getActivity().getApplicationContext();
    this.activity = binding.getActivity();
  }

  @Override
  public void onDetachedFromActivity() {
    this.context = null;
    this.activity = null;
  }

  // ActivityAware Ends
}